==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicIconFactory.h <==
// public class javax.swing.plaf.basic.BasicIconFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 933cf3db279fcb0a javax_swing_plaf_basic_BasicIconFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicIconFactory_H_
#define _JC_javax_swing_plaf_basic_BasicIconFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$sub_refs	_jc_javax_swing_plaf_basic_BasicIconFactory$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$refs	_jc_javax_swing_plaf_basic_BasicIconFactory$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$object	_jc_javax_swing_plaf_basic_BasicIconFactory$object;

typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$fields_struct	_jc_javax_swing_plaf_basic_BasicIconFactory$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory$vmethods	_jc_javax_swing_plaf_basic_BasicIconFactory$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory$vtable	_jc_javax_swing_plaf_basic_BasicIconFactory$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory$vtype	_jc_javax_swing_plaf_basic_BasicIconFactory$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicIconFactory$fields_struct _jc_javax_swing_plaf_basic_BasicIconFactory$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicIconFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory$object *);

// Static methods
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$createEmptyFrameIcon$66f99cd0550bce27(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getCheckBoxIcon$a8c3256d7e4b6444(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getCheckBoxMenuItemIcon$73c7e77a51188d31(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getMenuArrowIcon$4d8d78dde0862f7d(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getMenuItemArrowIcon$a6f3b4ac573b004e(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getMenuItemCheckIcon$5be9594c68ceaaa0(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getRadioButtonIcon$a0c0de2ff76ea137(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getRadioButtonMenuItemIcon$2eadacadb07cc372(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicIconFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicIconFactory$vmethods	javax_swing_plaf_basic_BasicIconFactory;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicIconFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicIconFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory$refs {
    _jc_javax_swing_plaf_basic_BasicIconFactory$sub_refs	javax_swing_plaf_basic_BasicIconFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicIconFactory$sub_nonrefs	javax_swing_plaf_basic_BasicIconFactory;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory$object {
	_jc_javax_swing_plaf_basic_BasicIconFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicIconFactory$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicIconFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicIconFactory$vtype _jc_javax_swing_plaf_basic_BasicIconFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicIconFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicIconFactory$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicIconFactory_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicIconFactory.h <==
// public class javax.swing.plaf.basic.BasicIconFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 933cf3db279fcb0a javax_swing_plaf_basic_BasicIconFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicIconFactory_H_
#define _JC_javax_swing_plaf_basic_BasicIconFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$sub_refs	_jc_javax_swing_plaf_basic_BasicIconFactory$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$refs	_jc_javax_swing_plaf_basic_BasicIconFactory$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$object	_jc_javax_swing_plaf_basic_BasicIconFactory$object;

typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory$fields_struct	_jc_javax_swing_plaf_basic_BasicIconFactory$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory$vmethods	_jc_javax_swing_plaf_basic_BasicIconFactory$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory$vtable	_jc_javax_swing_plaf_basic_BasicIconFactory$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory$vtype	_jc_javax_swing_plaf_basic_BasicIconFactory$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicIconFactory$fields_struct _jc_javax_swing_plaf_basic_BasicIconFactory$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicIconFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$createEmptyFrameIcon$66f99cd0550bce27(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getCheckBoxIcon$a8c3256d7e4b6444(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getCheckBoxMenuItemIcon$73c7e77a51188d31(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getMenuArrowIcon$4d8d78dde0862f7d(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getMenuItemArrowIcon$a6f3b4ac573b004e(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getMenuItemCheckIcon$5be9594c68ceaaa0(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getRadioButtonIcon$a0c0de2ff76ea137(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicIconFactory$method$getRadioButtonMenuItemIcon$2eadacadb07cc372(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicIconFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicIconFactory$vmethods	javax_swing_plaf_basic_BasicIconFactory;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicIconFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicIconFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory$refs {
    _jc_javax_swing_plaf_basic_BasicIconFactory$sub_refs	javax_swing_plaf_basic_BasicIconFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicIconFactory$sub_nonrefs	javax_swing_plaf_basic_BasicIconFactory;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory$object {
	_jc_javax_swing_plaf_basic_BasicIconFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicIconFactory$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicIconFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicIconFactory$vtype _jc_javax_swing_plaf_basic_BasicIconFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicIconFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicIconFactory$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicIconFactory_H_ */
